@@ -1,8 +1,8 @@
 #!/bin/sh
 #
 # Name:     dpl4hydra
-# Version:  0.9.6
-# Date:     2011-07-16
+# Version:  0.9.8
+# Date:     2011-11-24
 # Author:   Roland Kessler / Twitter: @rokessler
 # Synopsis: Generates a (d)efault (p)assword (l)ist as input for THC hydra.
 # Credits:  Thanks to van Hauser for support and fixing portability issues.
@@ -11,7 +11,7 @@
 usage ()
 {
 cat <<EOF
-dpl4hydra v0.9.6 (c) 2011 by Roland Kessler (@rokessler)
+dpl4hydra v0.9.8 (c) 2011 by Roland Kessler (@rokessler)
 
 Syntax: `basename $0` [help] | [refresh] | [BRAND] | [all]
 
@@ -71,7 +71,7 @@ refresh ()
   fi
     
   for SUBSITE in `cat $SUBSITES`; do
-    VENDOR=`echo $SUBSITE | awk -F"-" '{ print $2 }' | sed 's/.htm//'`
+    VENDOR=`echo $SUBSITE | awk -F"-" '{ print $3 }' | sed 's/.htm//'`
     echo "Downloading default passwords for ${VENDOR}... " | tr -d "\n"
     $FETCH $SUBSITE | grep -i tr | grep -i td | grep -i celltext | sed 's/<[^>]*>/,/g' | sed 's/,,*/,/g' | sed 's/^,//g' | tr -d "\r" >dpl4hydra_${VENDOR}.tmp || { echo "not found - skipping... " | tr -d "\n" ; }
     
@@ -97,7 +97,7 @@ refresh ()
   fi
   
   echo "Cleaning up and sorting ${FULLFILE}... " | tr -d "\n"
-  cat $FULLFILE | sed 's/(null)//g'  sed 's/(Null)//g'  sed 's/(NULL)//g' | sed 's/(blank)//g' | sed 's/(Blank)//g' | sed 's/(BLANK)//g' | sed 's/(none)//g' | sed 's/(None)//g' | sed 's/(NONE)//g' | sed 's/none//g' | sed 's/n\/a//g' | sed 's/&lt;/</g' | sed 's/&gt;/>/g' | sed 's/&nbsp;//g' | sort | uniq > $CLEANFILE
+  cat $FULLFILE | sed 's/(null)//g' | sed 's/(Null)//g' | sed 's/(NULL)//g' | sed 's/(blank)//g' | sed 's/(Blank)//g' | sed 's/(BLANK)//g' | sed 's/(none)//g' | sed 's/(None)//g' | sed 's/(NONE)//g' | sed 's/none//g' | sed 's/n\/a//g' | sed 's/&lt;/</g' | sed 's/&gt;/>/g' | sed 's/&nbsp;//g' | sort | uniq > $CLEANFILE
   mv $CLEANFILE $FULLFILE
   echo "done."
   echo
@@ -158,7 +158,7 @@ LOCALFILE="dpl4hydra_local.csv"
 INDEXSITE="dpl4hydra_index.tmp"
 SUBSITES="dpl4hydra_subs.tmp"
 CLEANFILE="dpl4hydra_clean.tmp"
-SITE="http://artofhacking.com/etc/passwd.htm"
+SITE="http://open-sez.me/passwd.htm"
 
 case $# in
 	0) usage
