@@ -62,7 +62,8 @@ int auth_flag = 0;
 
 char redirected_url_buff[2048] = "";
 int redirected_flag = 0;
-int redirected_cpt = 5;
+#define MAX_REDIRECT 5
+int redirected_cpt = MAX_REDIRECT;
 char cookie[2048] = "";
 
 extern char *webtarget;
@@ -134,6 +135,8 @@ int analyze_server_response(int s) {
       redirected_flag = 1;
     } else if (strstr(buf, "HTTP/1.1 401") != NULL) {
       auth_flag = 1;
+    } else if ((strstr(buf, "HTTP/1.1 403") != NULL) || (strstr(buf, "HTTP/1.1 404") != NULL)) {
+      return !success_cond;
     }
 
     if (hydra_strcasestr(buf, "Location: ") != NULL) {
@@ -144,6 +147,9 @@ int analyze_server_response(int s) {
       strncpy(str, startloc, sizeof(str) - 1);
       str[sizeof(str) - 1] = 0;
       endloc = strchr(str, '\n');
+      if (endloc != NULL)
+        *endloc = 0;
+      endloc = strchr(str, '\r');
       if (endloc != NULL)
         *endloc = 0;
       strcpy(redirected_url_buff, str);
@@ -233,7 +239,7 @@ int start_http_form(int s, char *ip, int port, unsigned char options, char *misc
   char *empty = "";
   char *login, *pass, buffer[4096];
   char header[2048], *upd3variables;
-  int found = 0;
+  int found = 0, i, j;
 
   memset(header, 0, sizeof(header));
   cookie[0] = 0;                // reset cookies from potential previous attempt
@@ -347,6 +353,7 @@ int start_http_form(int s, char *ip, int port, unsigned char options, char *misc
     sprintf(header, "Cookie: %s\r\n", cookie);
   }
   //if page was redirected, follow the location header
+  redirected_cpt = MAX_REDIRECT;
   while (!found && redirected_flag && (redirected_url_buff[0] != 0) && (redirected_cpt > 0)) {
     //we have to split the location
     char *startloc, *endloc;
@@ -364,6 +371,8 @@ int start_http_form(int s, char *ip, int port, unsigned char options, char *misc
 #endif
       found = !success_cond;
     } else {
+      //location could be either absolute http(s):// or / something
+      //or relative
       startloc = strstr(redirected_url_buff, "://");
       if (startloc != NULL) {
         startloc += strlen("://");
@@ -392,7 +401,31 @@ int start_http_form(int s, char *ip, int port, unsigned char options, char *misc
         }
       } else {
         strncpy(str2, webtarget, sizeof(str2));
-        strncpy(str3, redirected_url_buff, sizeof(str3));
+        if (redirected_url_buff[0] != '/') {
+          //it's a relative path, so we have to concatenate it
+          //with the path from the first url given
+          char *urlpath;
+          char urlpath_extracted[2048];
+          memset(urlpath_extracted, 0, sizeof(urlpath_extracted));
+
+          urlpath=strrchr(url, '/');
+          if (urlpath != NULL) {
+            strncpy(urlpath_extracted, url, urlpath-url);
+            sprintf(str3, "%.1000s/%.1000s", urlpath_extracted, redirected_url_buff);
+          } else {
+            sprintf(str3, "%.1000s/%.1000s", url, redirected_url_buff);
+          }
+        } else
+          strncpy(str3, redirected_url_buff, sizeof(str3));
+       if (debug)
+         hydra_report(stderr, "[DEBUG] host=%s redirect=%s origin=%s\n", str2, str3,url);
+      }
+      if (str3[0] != '/') {
+        j = strlen(str3);
+        str3[j + 1] = 0;
+        for (i = j; i > 0; i--)
+          str3[i] = str3[i - 1];
+        str3[0] = '/';
       }
 
       if (verbose)
@@ -425,7 +458,8 @@ int start_http_form(int s, char *ip, int port, unsigned char options, char *misc
     }
   }
 
-  if (found != 1) {
+  //if the last status is still 3xx, set it as a false
+  if (found != 1 && redirected_flag == 0 && redirected_cpt >= 0) {
     hydra_report_found_host(port, ip, "www-form", fp);
     hydra_completed_pair_found();
   } else {
