@@ -4,6 +4,7 @@
 extern int module_auth_type;
 extern char *HYDRA_EXIT;
 char *buf;
+static int http_proxy_auth_mechanism = AUTH_ERROR;
 
 int start_http_proxy(int s, char *ip, int port, unsigned char options, char *miscptr, FILE * fp) {
   char *empty = "";
@@ -31,30 +32,33 @@ int start_http_proxy(int s, char *ip, int port, unsigned char options, char *mis
     strcat(host, "\r\n");
   }
 
-  //send dummy request
-  sprintf(buffer, "GET %s HTTP/1.0\r\n%sUser-Agent: Mozilla/4.0 (Hydra)\r\n%s\r\n", url, host, header);
-  if (hydra_send(s, buffer, strlen(buffer), 0) < 0)
-    return 1;
+  if (http_proxy_auth_mechanism == AUTH_ERROR) {
+    //send dummy request
+    sprintf(buffer, "GET %s HTTP/1.0\r\n%sUser-Agent: Mozilla/4.0 (Hydra)\r\n%s\r\n", url, host, header);
+    if (hydra_send(s, buffer, strlen(buffer), 0) < 0)
+      return 1;
 
-  //receive first 40x
-  buf = hydra_receive_line(s);
-  while (buf != NULL && strstr(buf, "HTTP/") == NULL) {
-    free(buf);
+    //receive first 40x
     buf = hydra_receive_line(s);
-  }
+    while (buf != NULL && strstr(buf, "HTTP/") == NULL) {
+      free(buf);
+      buf = hydra_receive_line(s);
+    }
 
-  if (debug)
-    hydra_report(stderr, "S:%s\n", buf);
+    if (debug)
+      hydra_report(stderr, "S:%s\n", buf);
 
-  //after the first query we should have been disconnected from web server
-  s = hydra_disconnect(s);
-  if ((options & OPTION_SSL) == 0) {
-    s = hydra_connect_tcp(ip, port);
-  } else {
-    s = hydra_connect_ssl(ip, port);
+    //after the first query we should have been disconnected from web server
+    s = hydra_disconnect(s);
+    if ((options & OPTION_SSL) == 0) {
+      s = hydra_connect_tcp(ip, port);
+    } else {
+      s = hydra_connect_ssl(ip, port);
+    }
   }
 
   if (hydra_strcasestr(buf, "Proxy-Authenticate: Basic") != NULL) {
+    http_proxy_auth_mechanism = AUTH_BASIC;
     sprintf(buffer2, "%.50s:%.50s", login, pass);
     hydra_tobase64((unsigned char *) buffer2, strlen(buffer2), sizeof(buffer2));
     sprintf(buffer, "GET %s HTTP/1.0\r\n%sProxy-Authorization: Basic %s\r\nUser-Agent: Mozilla/4.0 (Hydra)\r\n%s\r\n", url, host, buffer2, header);
@@ -67,16 +71,25 @@ int start_http_proxy(int s, char *ip, int port, unsigned char options, char *mis
       free(buf);
       buf = hydra_receive_line(s);
     }
-    if (buf == NULL)
-      return 1;
-    else if (debug)
+
+    //if server cut the connection, just exit cleanly or 
+    //this will be an infinite loop
+    if (buf == NULL) {
+      if (verbose)
+	hydra_report(stderr, "[ERROR] Server did not answer\n", buf);
+      return 3;
+    }
+
+    if (debug)
       hydra_report(stderr, "S:%s\n", buf);
   } else {
     if (hydra_strcasestr(buf, "Proxy-Authenticate: NTLM") != NULL) {
 
       unsigned char buf1[4096];
       unsigned char buf2[4096];
+      char *pos = NULL;
 
+      http_proxy_auth_mechanism = AUTH_NTLM;
       //send auth and receive challenge
       //send auth request: let the server send it's own hostname and domainname
       buildAuthRequest((tSmbNtlmAuthRequest *) buf2, 0, NULL, NULL);
@@ -84,26 +97,36 @@ int start_http_proxy(int s, char *ip, int port, unsigned char options, char *mis
 
       /* to be portable, no snprintf, buffer is big enough so it cant overflow */
       //send the first..
-      sprintf(buffer, "GET %s HTTP/1.0\r\n%sProxy-Authorization: NTLM %s\r\nUser-Agent: Mozilla/4.0 (Hydra)\r\n%s\r\n", url, host, buf1, header);
+      sprintf(buffer, "GET %s HTTP/1.0\r\n%sProxy-Authorization: NTLM %s\r\nUser-Agent: Mozilla/4.0 (Hydra)\r\nProxy-Connection: keep-alive\r\n%s\r\n", url, host, buf1, header);
       if (hydra_send(s, buffer, strlen(buffer), 0) < 0)
         return 1;
 
       //receive challenge
       buf = hydra_receive_line(s);
-      while (buf != NULL && hydra_strcasestr(buf, "Proxy-Authenticate: NTLM ") == NULL) {
+      while (buf != NULL && (pos = hydra_strcasestr(buf, "Proxy-Authenticate: NTLM ")) == NULL) {
         free(buf);
         buf = hydra_receive_line(s);
       }
+      if (pos != NULL) {
+        char *str;
 
+        pos+=25;
+        if ((str=strchr(pos, '\r')) != NULL) {
+          pos[str - pos] = 0;
+        }
+        if ((str=strchr(pos, '\n')) != NULL) {
+          pos[str - pos] = 0; }
+      }
       //recover challenge
       if (buf != NULL) {
-        from64tobits((char *) buf1, buf + 25);
+        from64tobits((char *) buf1, pos);
         free(buf);
       }
+
       //Send response
       buildAuthResponse((tSmbNtlmAuthChallenge *) buf1, (tSmbNtlmAuthResponse *) buf2, 0, login, pass, NULL, NULL);
       to64frombits(buf1, buf2, SmbLength((tSmbNtlmAuthResponse *) buf2));
-      sprintf(buffer, "GET %s HTTP/1.0\r\n%sProxy-Authorization: NTLM %s\r\nUser-Agent: Mozilla/4.0 (Hydra)\r\n%s\r\n", url, host, buf1, header);
+      sprintf(buffer, "GET %s HTTP/1.0\r\n%sProxy-Authorization: NTLM %s\r\nUser-Agent: Mozilla/4.0 (Hydra)\r\nProxy-Connection: keep-alive\r\n%s\r\n", url, host, buf1, header);
       if (debug)
         hydra_report(stderr, "C:%s\n", buffer);
       if (hydra_send(s, buffer, strlen(buffer), 0) < 0)
@@ -123,6 +146,7 @@ int start_http_proxy(int s, char *ip, int port, unsigned char options, char *mis
 
         char *pbuffer;
 
+        http_proxy_auth_mechanism = AUTH_DIGESTMD5;
         pbuffer = hydra_strcasestr(buf, "Proxy-Authenticate: Digest ");
         strncpy(buffer, pbuffer + strlen("Proxy-Authenticate: Digest "), sizeof(buffer));
         buffer[sizeof(buffer) - 1] = '\0';
@@ -163,15 +187,15 @@ int start_http_proxy(int s, char *ip, int port, unsigned char options, char *mis
   }
 
   ptr = ((char *) index(buf, ' ')) + 1;
-  if (*ptr == '2' || (*ptr == '3' && *(ptr + 2) == '1')) {
+  if (*ptr == '2' || (*ptr == '3' && *(ptr + 2) == '1') || (*ptr == '3' && *(ptr + 2) == '2')) {
     hydra_report_found_host(port, ip, "http-proxy", fp);
     hydra_completed_pair_found();
   } else {
     if (*ptr != '4')
-      hydra_report(stderr, "Unusual return code: %c for %s:%s\n", (char) *(index(buf, ' ') + 1), login, pass);
+      hydra_report(stderr, "[INFO] Unusual return code: %c for %s:%s\n", (char) *(index(buf, ' ') + 1), login, pass);
     else
       if (verbose && *(ptr + 2) == '3')
-        printf("Potential success, could be false positive: %s:%s\n", login, pass);
+        hydra_report(stderr, "[INFO] Potential success, could be false positive: %s:%s\n", login, pass);
     hydra_completed_pair();
   }
 
@@ -209,6 +233,7 @@ void service_http_proxy(char *ip, int sp, unsigned char options, char *miscptr,
           sock = hydra_connect_ssl(ip, mysslport);
           port = mysslport;
         }
+
         if (sock < 0) {
           fprintf(stderr, "Error: Child with pid %d terminating, can not connect\n", (int) getpid());
           hydra_child_exit(1);
