@@ -64,6 +64,7 @@ int start_http(int s, char *ip, int port, unsigned char options, char *miscptr,
   case AUTH_NTLM:{
       unsigned char buf1[4096];
       unsigned char buf2[4096];
+      char *pos = NULL;
 
       //send auth and receive challenge
       //send auth request: let the server send it's own hostname and domainname
@@ -88,7 +89,7 @@ int start_http(int s, char *ip, int port, unsigned char options, char *miscptr,
 
       //receive challenge
       buf = hydra_receive_line(s);
-      while (buf != NULL && hydra_strcasestr(buf, "WWW-Authenticate: NTLM ") == NULL) {
+      while (buf != NULL && (pos = hydra_strcasestr(buf, "WWW-Authenticate: NTLM ")) == NULL) {
         free(buf);
         buf = hydra_receive_line(s);
       }
@@ -96,8 +97,19 @@ int start_http(int s, char *ip, int port, unsigned char options, char *miscptr,
       if (buf == NULL)
         return 1;
 
+      if (pos != NULL) {
+        char *str;
+
+        pos+=23;
+        if ((str=strchr(pos, '\r')) != NULL) {
+          pos[str - pos] = 0;
+        }
+        if ((str=strchr(pos, '\n')) != NULL) {
+          pos[str - pos] = 0; }
+      }
+
       //recover challenge
-      from64tobits((char *) buf1, buf + 23);
+      from64tobits((char *) buf1, pos);
       free(buf);
 
       //Send response
@@ -132,8 +144,13 @@ int start_http(int s, char *ip, int port, unsigned char options, char *miscptr,
     buf = hydra_receive_line(s);
   }
 
-  if (buf == NULL)
-    return 1;
+  //if server cut the connection, just exit cleanly or 
+  //this will be an infinite loop
+  if (buf == NULL) {
+    if (verbose)
+      hydra_report(stderr, "[ERROR] Server did not answer\n", buf);
+    return 3;
+  }
 
   if (debug)
     hydra_report(stderr, "S:%s\n", buf);
