@@ -607,8 +607,6 @@ void hydra_report_debug(FILE * st, char *format, ...) {
   if (format == NULL) {
     fprintf(stderr, "[ERROR] no msg passed.\n");
   } else {
-    if (format[strlen(format) - 1] == '\n')
-      format[strlen(format) - 1] = 0;
     va_start(ap, format);
     memset(bufOut, 0, sizeof(bufOut));
     memset(buf, 0, 512);
@@ -760,6 +758,19 @@ int hydra_recv(int socket, char *buf, int length) {
   return ret;
 }
 
+int hydra_recv_nb(int socket, char *buf, int length) {
+  int ret;
+  if (hydra_data_ready_timed(socket, (long) waittime, 0) > 0) {
+    if ((ret = internal__hydra_recv(socket, buf, length)) <= 0) {
+      buf[0] = 0;
+      return ret;
+    }
+    if (debug)
+      hydra_report_debug(stderr, "DEBUG_RECV_BEGIN|%s|END [pid:%d ret:%d]", buf, getpid(), ret);
+  }
+  return ret;
+}
+
 char *hydra_receive_line(int socket) {
   char buf[1024], *buff;
   int i, j = 1, k, got = 0;
@@ -1062,3 +1073,61 @@ char *hydra_strcasestr(const char *haystack, const char *needle) {
   }
   return NULL;
 }
+
+void hydra_dump_data(unsigned char *buf, int len, char *text) {
+  unsigned char *p = (unsigned char *) buf;
+  unsigned char lastrow_data[16];
+  int rows = len / 16;
+  int lastrow = len % 16;
+  int i, j;
+
+  if (buf == NULL || len == 0)
+    return;
+
+  if (text != NULL && text[0] != 0)
+    printf("%s (%d bytes):\n", text, len);
+  for (i = 0; i < rows; i++) {
+    printf("%04hx:  ", i * 16);
+    for (j = 0; j < 16; j++) {
+      printf("%02x", p[(i * 16) + j]);
+      if (j % 2 == 1)
+        printf(" ");
+    }
+    printf("   [ ");
+    for (j = 0; j < 16; j++) {
+      if (isprint(p[(i * 16) + j]))
+        printf("%c", p[(i * 16) + j]);
+      else
+        printf(".");
+    }
+    printf(" ]\n");
+  }
+  if (lastrow > 0) {
+    memset(lastrow_data, 0, sizeof(lastrow_data));
+    memcpy(lastrow_data, p + len - lastrow, lastrow);
+    printf("%04hx:  ", i * 16);
+    for (j = 0; j < lastrow; j++) {
+      printf("%02x", p[(i * 16) + j]);
+      if (j % 2 == 1)
+        printf(" ");
+    }
+    while (j < 16) {
+      printf("  ");
+      if (j % 2 == 1)
+        printf(" ");
+      j++;
+    }
+    printf("   [ ");
+    for (j = 0; j < lastrow; j++) {
+      if (isprint(p[(i * 16) + j]))
+        printf("%c", p[(i * 16) + j]);
+      else
+        printf(".");
+    }
+    while (j < 16) {
+      printf(" ");
+      j++;
+    }
+    printf(" ]\n");
+  }
+}
