@@ -23,6 +23,7 @@ extern int hydra_connect_udp(char *host, int port);
 extern int hydra_disconnect(int socket);
 extern int hydra_data_ready(int socket);
 extern int hydra_recv(int socket, char *buf, int length);
+extern int hydra_recv_nb(int socket, char *buf, int length);
 extern char *hydra_receive_line(int socket);
 extern int hydra_send(int socket, char *buf, int size, int options);
 extern int make_to_lower(char *buf);
@@ -32,6 +33,7 @@ extern void hydra_dump_asciihex(unsigned char *string, int length);
 extern void hydra_set_srcport(int port);
 extern char *hydra_address2string(char *address);
 extern char *hydra_strcasestr(const char *haystack, const char *needle);
+extern void hydra_dump_data(unsigned char *buf, int len, char *text);
 
 #ifdef HAVE_PCRE
 int hydra_string_match(char *str, const char *regex);
