@@ -17,7 +17,7 @@ int fail_cnt;
 int start_socks5(int s, char *ip, int port, unsigned char options, char *miscptr, FILE * fp) {
   char *empty = "";
   char *login, *pass, buffer[300];
-  int pport;
+  int pport, fud = 0;
 
   if (strlen(login = hydra_get_next_login()) == 0)
     login = empty;
@@ -87,6 +87,8 @@ int start_socks5(int s, char *ip, int port, unsigned char options, char *miscptr
     if ((buf = (unsigned char *) hydra_receive_line(s)) != NULL) {
       if (buf[1] == 0 || buf[1] == 32) {
         hydra_report_found_host(port, ip, "socks5", fp);
+        hydra_completed_pair_found();
+        fud = 1;
       } else if (buf[1] != 2) {
         hydra_report_found_host_msg(port, ip, "socks5", fp, "might be a false positive!");
       }
@@ -94,7 +96,8 @@ int start_socks5(int s, char *ip, int port, unsigned char options, char *miscptr
   }
   if (buf != NULL)
     free(buf);
-  hydra_completed_pair();
+  if (fud == 0)
+    hydra_completed_pair();
   if (memcmp(hydra_get_next_pair(), &HYDRA_EXIT, sizeof(HYDRA_EXIT)) == 0)
     return 3;
 
