@@ -255,7 +255,7 @@ int start_xmpp(int s, char *ip, int port, unsigned char options, char *miscptr,
     return 2;
   }
   if (strstr(buf, "<failure")) {
-    hydra_report(stderr, "[ERROR]: Protocol failure, try using another auth method. %s\n", strstr(buf, "<failure"));
+    hydra_report(stderr, "[ERROR] Protocol failure, try using another auth method. %s\n", strstr(buf, "<failure"));
   }
   return 3;
 }
