@@ -485,7 +485,7 @@ void sasl_digest_md5(char *result, char *login, char *pass, char *buffer, char *
 
   //xmpp case, some xmpp server is not sending the realm so we have to set it up
   if ((strlen(realm)==0) && (strstr(type, "xmpp") != NULL))
-    snprintf(realm, sizeof(realm), miscptr);
+    snprintf(realm, sizeof(realm), "%s", miscptr);
 
   //compute ha1
   //support for algo = MD5
